@@ -8,6 +8,7 @@ from nonebot.internal.matcher import Matcher
 from nonebot.message import run_preprocessor
 
 from .config import conf
+from .errors import RateLimitedError, PermissionDeniedError
 from .service import Service, get_nonebot_service
 
 _matcher_service_mapping: Dict[Type[Matcher], Service] = {}
@@ -25,10 +26,16 @@ async def check(matcher: Matcher, bot: Bot, event: Event):
     if service is None:
         return
 
-    allow = await service.check(bot, event)
-
-    if not allow:
-        raise IgnoredException("permission denied by nonebot_plugin_access_control")
+    try:
+        await service.check(bot, event, throw_on_fail=True)
+    except PermissionDeniedError:
+        if conf.access_control_reply_on_permission_denied:
+            await matcher.send(conf.access_control_reply_on_permission_denied)
+        raise IgnoredException("permission denied (by nonebot_plugin_access_control)")
+    except RateLimitedError:
+        if conf.access_control_reply_on_rate_limited:
+            await matcher.send(conf.access_control_reply_on_rate_limited)
+        raise IgnoredException("rate limited (by nonebot_plugin_access_control)")
 
 
 if conf.access_control_auto_patch_enabled:
